import os
import sys

runPath = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.join(runPath, "../.."))

from dateutil.parser import parse as parse_datetime
from lib.Config import Configuration as conf

data = {
    "cves": [
        {
            "id": "CVE-2015-0001",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2015-01-13T22:59:00.000Z", ignoretz=True),
            "modified": parse_datetime("2018-10-12T22:07:00.000Z", ignoretz=True),
            "lastModified": parse_datetime("2018-10-12T22:07:00.000Z", ignoretz=True),
            "summary": 'The Windows Error Reporting (WER) component in Microsoft Windows 8, Windows 8.1, Windows Server 2012 Gold and R2, and Windows RT Gold and 8.1 allows local users to bypass the Protected Process Light protection mechanism and read the contents of arbitrary process-memory locations by leveraging administrative privileges, aka "Windows Error Reporting Security Feature Bypass Vulnerability."',
            "access": {
                "authentication": "NONE",
                "complexity": "MEDIUM",
                "vector": "LOCAL",
            },
            "impact": {
                "availability": "NONE",
                "confidentiality": "PARTIAL",
                "integrity": "NONE",
            },
            "cvss": 1.9,
            "cvssTime": parse_datetime("2018-10-12T22:07:00.000Z", ignoretz=True),
            "cvssVector": "AV:L/AC:M/Au:N/C:P/I:N/A:N",
            "references": [
                "http://packetstormsecurity.com/files/134392/Microsoft-Windows-8.1-Ahcache.sys-NtApphelpCacheControl-Privilege-Escalation.html",
                "http://secunia.com/advisories/62134",
                "http://www.securityfocus.com/bid/71927",
                "https://docs.microsoft.com/en-us/security-updates/securitybulletins/2015/ms15-006",
                "https://exchange.xforce.ibmcloud.com/vulnerabilities/99513",
                "https://exchange.xforce.ibmcloud.com/vulnerabilities/99514",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:o:microsoft:windows_8:-:*:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_8.1:-:*:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_rt:-:gold:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_rt_8.1:-:*:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2012:-:gold:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2012:r2:*:*:*:*:x64:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:o:microsoft:windows_8:-:*:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_8.1:-:*:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_rt:-:gold:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_rt_8.1:-:*:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2012:-:gold:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2012:r2:*:*:*:*:x64:*:*",
            ],
            "vendors": ["microsoft"],
            "products": [
                "windows_8",
                "windows_8.1",
                "windows_rt",
                "windows_rt_8.1",
                "windows_server_2012",
            ],
            "vulnerable_product_stems": [
                "cpe:2.3:o:microsoft:windows_8",
                "cpe:2.3:o:microsoft:windows_8.1",
                "cpe:2.3:o:microsoft:windows_rt",
                "cpe:2.3:o:microsoft:windows_rt_8.1",
                "cpe:2.3:o:microsoft:windows_server_2012",
            ],
            "vulnerable_configuration_stems": [
                "cpe:2.3:o:microsoft:windows_8",
                "cpe:2.3:o:microsoft:windows_8.1",
                "cpe:2.3:o:microsoft:windows_rt",
                "cpe:2.3:o:microsoft:windows_rt_8.1",
                "cpe:2.3:o:microsoft:windows_server_2012",
            ],
            "cwe": ["CWE-264"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2018-0004",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2018-01-10T22:29:00.000Z", ignoretz=True),
            "modified": parse_datetime("2019-10-09T23:30:00.000Z", ignoretz=True),
            "lastModified": parse_datetime("2019-10-09T23:30:00.000Z", ignoretz=True),
            "summary": "A sustained sequence of different types of normal transit traffic can trigger a high CPU consumption denial of service condition in the Junos OS register and schedule software interrupt handler subsystem when a specific command is issued to the device. This affects one or more threads and conversely one or more running processes running on the system. Once this occurs, the high CPU event(s) affects either or both the forwarding and control plane. As a result of this condition the device can become inaccessible in either or both the control and forwarding plane and stops forwarding traffic until the device is rebooted. The issue will reoccur after reboot upon receiving further transit traffic. Score: 5.7 MEDIUM (CVSS:3.0/AV:A/AC:L/PR:N/UI:R/S:U/C:N/I:N/A:H) For network designs utilizing layer 3 forwarding agents or other ARP through layer 3 technologies, the score is slightly higher. Score: 6.5 MEDIUM (CVSS:3.0/AV:N/AC:L/PR:N/UI:R/S:U/C:N/I:N/A:H) If the following entry exists in the RE message logs then this may indicate the issue is present. This entry may or may not appear when this issue occurs. /kernel: Expensive timeout(9) function: Affected releases are Juniper Networks Junos OS: 12.1X46 versions prior to 12.1X46-D50; 12.3X48 versions prior to 12.3X48-D30; 12.3R versions prior to 12.3R12-S7; 14.1 versions prior to 14.1R8-S4, 14.1R9; 14.1X53 versions prior to 14.1X53-D30, 14.1X53-D34; 14.2 versions prior to 14.2R8; 15.1 versions prior to 15.1F6, 15.1R3; 15.1X49 versions prior to 15.1X49-D40; 15.1X53 versions prior to 15.1X53-D31, 15.1X53-D33, 15.1X53-D60. No other Juniper Networks products or platforms are affected by this issue.",
            "access": {
                "authentication": "NONE",
                "complexity": "MEDIUM",
                "vector": "NETWORK",
            },
            "impact": {
                "availability": "COMPLETE",
                "confidentiality": "NONE",
                "integrity": "NONE",
            },
            "cvss": 7.1,
            "cvssTime": parse_datetime("2019-10-09T23:30:00.000Z", ignoretz=True),
            "cvssVector": "AV:N/AC:M/Au:N/C:N/I:N/A:C",
            "references": [
                "http://www.securitytracker.com/id/1040183",
                "https://kb.juniper.net/JSA10832",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:o:juniper:junos:12.1x46:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d15:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d30:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d35:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d40:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d45:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d15:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r11:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r12:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r6:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r7:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r8:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r9:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r6:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r7:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r9:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d15:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d16:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d26:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d27:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d34:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r6:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r7:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:a1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d30:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d35:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d21:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d210:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d30:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d33:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d60:*:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:o:juniper:junos:12.1x46:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d15:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d30:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d35:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d40:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.1x46:d45:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d15:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3x48:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r11:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r12:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r6:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r7:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r8:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:12.3:r9:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r6:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r7:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1:r9:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d15:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d16:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d26:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d27:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.1x53:d34:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r6:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:14.2:r7:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:a1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s1:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s2:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f2-s4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f4:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:f5:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1:r3:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d30:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x49:d35:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:*:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d10:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d20:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d21:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d210:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d25:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d30:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d33:*:*:*:*:*:*",
                "cpe:2.3:o:juniper:junos:15.1x53:d60:*:*:*:*:*:*",
            ],
            "vendors": ["juniper"],
            "products": ["junos"],
            "vulnerable_product_stems": ["cpe:2.3:o:juniper:junos"],
            "vulnerable_configuration_stems": ["cpe:2.3:o:juniper:junos"],
            "cwe": ["CWE-400"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2020-0079",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2020-04-17T19:15:00.000Z", ignoretz=True),
            "modified": parse_datetime("2020-04-23T18:56:00.000Z", ignoretz=True),
            "lastModified": parse_datetime("2020-04-23T18:56:00.000Z", ignoretz=True),
            "summary": "In decrypt_1_2 of CryptoPlugin.cpp, there is a possible out of bounds write due to stale pointer. This could lead to local escalation of privilege with no additional execution privileges needed. User interaction is not needed for exploitation.Product: AndroidVersions: Android-9 Android-10Android ID: A-144506242",
            "access": {
                "authentication": "NONE",
                "complexity": "LOW",
                "vector": "LOCAL",
            },
            "impact": {
                "availability": "PARTIAL",
                "confidentiality": "PARTIAL",
                "integrity": "PARTIAL",
            },
            "cvss": 4.6,
            "cvssTime": parse_datetime("2020-04-23T18:56:00.000Z", ignoretz=True),
            "cvssVector": "AV:L/AC:L/Au:N/C:P/I:P/A:P",
            "references": ["https://source.android.com/security/bulletin/2020-04-01"],
            "vulnerable_configuration": [
                "cpe:2.3:o:google:android:9.0:*:*:*:*:*:*:*",
                "cpe:2.3:o:google:android:10.0:*:*:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:o:google:android:9.0:*:*:*:*:*:*:*",
                "cpe:2.3:o:google:android:10.0:*:*:*:*:*:*:*",
            ],
            "vendors": ["google"],
            "products": ["android"],
            "vulnerable_product_stems": ["cpe:2.3:o:google:android"],
            "vulnerable_configuration_stems": ["cpe:2.3:o:google:android"],
            "cwe": ["CWE-787"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2010-3333",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2010-11-10T03:00:00.000Z", ignoretz=True),
            "modified": parse_datetime("2018-10-12T21:58:00.000Z", ignoretz=True),
            "lastModified": parse_datetime("2018-10-12T21:58:00.000Z", ignoretz=True),
            "summary": 'Stack-based buffer overflow in Microsoft Office XP SP3, Office 2003 SP3, Office 2007 SP2, Office 2010, Office 2004 and 2008 for Mac, Office for Mac 2011, and Open XML File Format Converter for Mac allows remote attackers to execute arbitrary code via crafted RTF data, aka "RTF Stack Buffer Overflow Vulnerability."',
            "access": {
                "authentication": "NONE",
                "complexity": "MEDIUM",
                "vector": "NETWORK",
            },
            "impact": {
                "availability": "COMPLETE",
                "confidentiality": "COMPLETE",
                "integrity": "COMPLETE",
            },
            "cvss": 9.3,
            "cvssTime": parse_datetime("2018-10-12T21:58:00.000Z", ignoretz=True),
            "cvssVector": "AV:N/AC:M/Au:N/C:C/I:C/A:C",
            "references": [
                "http://labs.idefense.com/intelligence/vulnerabilities/display.php?id=880",
                "http://secunia.com/advisories/38521",
                "http://secunia.com/advisories/42144",
                "http://securityreason.com/securityalert/8293",
                "http://www.securityfocus.com/bid/44652",
                "http://www.securitytracker.com/id?1024705",
                "http://www.us-cert.gov/cas/techalerts/TA10-313A.html",
                "http://www.vupen.com/english/advisories/2010/2923",
                "https://docs.microsoft.com/en-us/security-updates/securitybulletins/2010/ms10-087",
                "https://oval.cisecurity.org/repository/search/definition/oval%3Aorg.mitre.oval%3Adef%3A11931",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:a:microsoft:office:2003:sp3:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2004:*:mac:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2007:sp2:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2008:*:mac:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2010:*:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2011:*:mac:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:xp:sp3:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:open_xml_file_format_converter:*:*:mac:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:a:microsoft:office:2003:sp3:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2004:*:mac:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2007:sp2:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2008:*:mac:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2010:*:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:2011:*:mac:*:*:*:*:*",
                "cpe:2.3:a:microsoft:office:xp:sp3:*:*:*:*:*:*",
                "cpe:2.3:a:microsoft:open_xml_file_format_converter:*:*:mac:*:*:*:*:*",
            ],
            "vendors": ["microsoft"],
            "products": ["office", "open_xml_file_format_converter"],
            "vulnerable_product_stems": [
                "cpe:2.3:a:microsoft:office",
                "cpe:2.3:a:microsoft:open_xml_file_format_converter",
            ],
            "vulnerable_configuration_stems": [
                "cpe:2.3:a:microsoft:office",
                "cpe:2.3:a:microsoft:open_xml_file_format_converter",
            ],
            "cwe": ["CWE-119"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2017-12231",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2017-09-29T01:34:00.000Z", ignoretz=True),
            "modified": parse_datetime("2019-10-09T23:22:00.000Z", ignoretz=True),
            "lastModified": parse_datetime("2019-10-09T23:22:00.000Z", ignoretz=True),
            "summary": "A vulnerability in the implementation of Network Address Translation (NAT) functionality in Cisco IOS 12.4 through 15.6 could allow an unauthenticated, remote attacker to cause a denial of service (DoS) condition on an affected device. The vulnerability is due to the improper translation of H.323 messages that use the Registration, Admission, and Status (RAS) protocol and are sent to an affected device via IPv4 packets. An attacker could exploit this vulnerability by sending a crafted H.323 RAS packet through an affected device. A successful exploit could allow the attacker to cause the affected device to crash and reload, resulting in a DoS condition. This vulnerability affects Cisco devices that are configured to use an application layer gateway with NAT (NAT ALG) for H.323 RAS messages. By default, a NAT ALG is enabled for H.323 RAS messages. Cisco Bug IDs: CSCvc57217.",
            "access": {
                "authentication": "NONE",
                "complexity": "LOW",
                "vector": "NETWORK",
            },
            "impact": {
                "availability": "COMPLETE",
                "confidentiality": "NONE",
                "integrity": "NONE",
            },
            "cvss": 7.8,
            "cvssTime": parse_datetime("2019-10-09T23:22:00.000Z", ignoretz=True),
            "cvssVector": "AV:N/AC:L/Au:N/C:N/I:N/A:C",
            "references": [
                "http://www.securityfocus.com/bid/101039",
                "http://www.securitytracker.com/id/1039449",
                "https://tools.cisco.com/security/center/content/CiscoSecurityAdvisory/cisco-sa-20170927-nat",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao3a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao20s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap1n:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.0\\(2\\)sqd7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.1\\(2\\)sg7a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e5b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(3\\)ex:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m8:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m10:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m11:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)s7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5a\\)e1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jbb6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc50:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc51:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jca7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jd7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jda3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)je1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jf1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnc4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnd2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnp2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnp4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpc3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m8:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m8a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s8:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s8a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(1\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(1\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(2\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(2\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m5:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s5:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s5a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s6b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s7a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)t3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m4a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s1a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s2b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s3a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4d:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s5:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s1a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1c:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)t:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)t1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m1b:*:*:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao3a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao20s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap1n:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.0\\(2\\)sqd7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.1\\(2\\)sg7a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e5b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(3\\)ex:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m8:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m10:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)m11:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)s7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5a\\)e1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jbb6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc50:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc51:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jca7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jd7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jda3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)je1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jf1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnc4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnd2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnp2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnp4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpc3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m8:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)m8a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s8:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s8a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)s9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(1\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(1\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(2\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(2\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m5:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)m6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s5:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s5a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s6:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s6b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.4\\(3\\)s7a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)t3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(1\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(2\\)t4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)m4a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s1a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s2b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s3a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s4d:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.5\\(3\\)s5:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s1a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1c:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)t:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)t1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)t2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(3\\)m1b:*:*:*:*:*:*:*",
            ],
            "vendors": ["cisco"],
            "products": ["ios"],
            "vulnerable_product_stems": ["cpe:2.3:o:cisco:ios"],
            "vulnerable_configuration_stems": ["cpe:2.3:o:cisco:ios"],
            "cwe": ["NVD-CWE-noinfo"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2017-12233",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2017-09-29T01:34:00.000Z", ignoretz=True),
            "modified": parse_datetime("2019-10-09T23:22:00.000Z", ignoretz=True),
            "lastModified": parse_datetime("2019-10-09T23:22:00.000Z", ignoretz=True),
            "summary": "Multiple vulnerabilities in the implementation of the Common Industrial Protocol (CIP) feature in Cisco IOS 12.4 through 15.6 could allow an unauthenticated, remote attacker to cause an affected device to reload, resulting in a denial of service (DoS) condition. The vulnerabilities are due to the improper parsing of crafted CIP packets destined to an affected device. An attacker could exploit these vulnerabilities by sending crafted CIP packets to be processed by an affected device. A successful exploit could allow the attacker to cause the affected device to reload, resulting in a DoS condition. Cisco Bug IDs: CSCuz95334.",
            "access": {
                "authentication": "NONE",
                "complexity": "LOW",
                "vector": "NETWORK",
            },
            "impact": {
                "availability": "COMPLETE",
                "confidentiality": "NONE",
                "integrity": "NONE",
            },
            "cvss": 7.8,
            "cvssTime": parse_datetime("2019-10-09T23:22:00.000Z", ignoretz=True),
            "cvssVector": "AV:N/AC:L/Au:N/C:N/I:N/A:C",
            "references": [
                "http://www.securityfocus.com/bid/101038",
                "http://www.securitytracker.com/id/1039459",
                "https://tools.cisco.com/security/center/content/CiscoSecurityAdvisory/cisco-sa-20170927-cip",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao3a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao20s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap1n:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.0\\(2\\)sqd7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.1\\(2\\)sg7a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e5b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)eb:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)eb1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)eb2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(3\\)ex:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5a\\)e1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jbb6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc50:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc51:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jca7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jda3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)je1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnc4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnd2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnp2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpc3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s1a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1c:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp2a:*:*:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao3a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jao20s:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap1n:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:12.4\\(25e\\)jap9:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.0\\(2\\)sqd7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.1\\(2\\)sg7a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)e5b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)eb:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)eb1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(2\\)eb2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(3\\)ex:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(4\\)ec2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5\\)e2b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.2\\(5a\\)e1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jbb6a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc50:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jc51:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jca7:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jda3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)je1:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnc4:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnd2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jnp2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpb2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.3\\(3\\)jpc3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(1\\)s1a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s0a:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s2:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)s3:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1b:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp1c:*:*:*:*:*:*:*",
                "cpe:2.3:o:cisco:ios:15.6\\(2\\)sp2a:*:*:*:*:*:*:*",
            ],
            "vendors": ["cisco"],
            "products": ["ios"],
            "vulnerable_product_stems": ["cpe:2.3:o:cisco:ios"],
            "vulnerable_configuration_stems": ["cpe:2.3:o:cisco:ios"],
            "cwe": ["CWE-20"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2017-0123",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2017-03-17T00:59:00.000Z"),
            "modified": parse_datetime("2017-08-16T01:29:00.000Z"),
            "lastModified": parse_datetime("2017-08-16T01:29:00.000Z"),
            "summary": 'Uniscribe in Microsoft Windows Vista SP2, Windows Server 2008 SP2 and R2 SP1, and Windows 7 SP1 allows remote attackers to obtain sensitive information from process memory via a crafted web site, aka "Uniscribe Information Disclosure Vulnerability." CVE-2017-0085, CVE-2017-0091, CVE-2017-0092, CVE-2017-0111, CVE-2017-0112, CVE-2017-0113, CVE-2017-0114, CVE-2017-0115, CVE-2017-0116, CVE-2017-0117, CVE-2017-0118, CVE-2017-0119, CVE-2017-0120, CVE-2017-0121, CVE-2017-0122, CVE-2017-0124, CVE-2017-0125, CVE-2017-0126, CVE-2017-0127, and CVE-2017-0128.',
            "access": {
                "authentication": "NONE",
                "complexity": "MEDIUM",
                "vector": "NETWORK",
            },
            "impact": {
                "availability": "NONE",
                "confidentiality": "PARTIAL",
                "integrity": "NONE",
            },
            "cvss": 4.3,
            "cvssTime": parse_datetime("2017-08-16T01:29:00.000Z"),
            "cvssVector": "AV:N/AC:M/Au:N/C:P/I:N/A:N",
            "references": [
                "http://www.securityfocus.com/bid/96669",
                "http://www.securitytracker.com/id/1037992",
                "https://portal.msrc.microsoft.com/en-US/security-guidance/advisory/CVE-2017-0123",
                "https://www.exploit-db.com/exploits/41655/",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:o:microsoft:windows_7:*:sp1:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2008:*:sp2:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2008:r2:sp1:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_vista:*:sp2:*:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:o:microsoft:windows_7:*:sp1:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2008:*:sp2:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_server_2008:r2:sp1:*:*:*:*:*:*",
                "cpe:2.3:o:microsoft:windows_vista:*:sp2:*:*:*:*:*:*",
            ],
            "vendors": ["microsoft"],
            "products": ["windows_7", "windows_server_2008", "windows_vista"],
            "vulnerable_product_stems": [
                "cpe:2.3:o:microsoft:windows_7",
                "cpe:2.3:o:microsoft:windows_server_2008",
                "cpe:2.3:o:microsoft:windows_vista",
            ],
            "vulnerable_configuration_stems": [
                "cpe:2.3:o:microsoft:windows_7",
                "cpe:2.3:o:microsoft:windows_server_2008",
                "cpe:2.3:o:microsoft:windows_vista",
            ],
            "cwe": ["CWE-200"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "id": "CVE-2013-0270",
            "assigner": "cve@mitre.org",
            "published": parse_datetime("2013-04-12T22:55:00.000Z"),
            "modified": parse_datetime("2018-11-16T14:38:00.000Z"),
            "lastModified": parse_datetime("2018-11-16T14:38:00.000Z"),
            "summary": "OpenStack Keystone Grizzly before 2013.1, Folsom, and possibly earlier allows remote attackers to cause a denial of service (CPU and memory consumption) via a large HTTP request, as demonstrated by a long tenant_name when requesting a token.",
            "access": {
                "authentication": "NONE",
                "complexity": "LOW",
                "vector": "NETWORK",
            },
            "impact": {
                "availability": "PARTIAL",
                "confidentiality": "NONE",
                "integrity": "NONE",
            },
            "cvss": 5.0,
            "cvssTime": parse_datetime("2018-11-16T14:38:00.000Z"),
            "cvssVector": "AV:N/AC:L/Au:N/C:N/I:N/A:P",
            "references": [
                "http://rhn.redhat.com/errata/RHSA-2013-0708.html",
                "https://bugs.launchpad.net/keystone/+bug/1099025",
                "https://bugzilla.redhat.com/show_bug.cgi?id=909012",
                "https://github.com/openstack/keystone/commit/7691276b869a86c2b75631d5bede9f61e030d9d8",
                "https://github.com/openstack/keystone/commit/82c87e5638ebaf9f166a9b07a0155291276d6fdc",
                "https://launchpad.net/keystone/grizzly/2013.1",
            ],
            "vulnerable_configuration": [
                "cpe:2.3:a:openstack:keystone:2012.1:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.1.1:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.1.2:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.1.3:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2:milestone1:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2:milestone2:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.1:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.2:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.3:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.4:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2013.1:milestone1:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2013.1:milestone2:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2013.1:milestone3:*:*:*:*:*:*",
            ],
            "vulnerable_product": [
                "cpe:2.3:a:openstack:keystone:2012.1:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.1.1:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.1.2:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.1.3:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2:milestone1:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2:milestone2:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.1:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.2:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.3:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2012.2.4:*:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2013.1:milestone1:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2013.1:milestone2:*:*:*:*:*:*",
                "cpe:2.3:a:openstack:keystone:2013.1:milestone3:*:*:*:*:*:*",
            ],
            "vendors": ["openstack"],
            "products": ["keystone"],
            "vulnerable_product_stems": ["cpe:2.3:a:openstack:keystone"],
            "vulnerable_configuration_stems": ["cpe:2.3:a:openstack:keystone"],
            "cwe": ["CWE-119"],
            "vulnerable_configuration_cpe_2_2": [],
        },
        {
            "_id": "67b5f11d515bf794df9bb68b",
            "assigner": "security-advisories@github.com",
            "cvss": None,
            "cvss3": None,
            "cvss4": 10,
            "cvss4Source": "security-advisories@github.com",
            "cvss4Time": parse_datetime("2025-02-18T21:15:28.583000"),
            "cvss4Type": "Secondary",
            "cvss4Vector": "CVSS:4.0/AV:N/AC:L/AT:N/PR:N/UI:N/VC:H/VI:H/VA:H/SC:H/SI:H/SA:H/E:X/CR:X/IR:X/AR:X/MAV:X/MAC:X/MAT:X/MPR:X/MUI:X/MVC:X/MVI:X/MVA:X/MSC:X/MSI:X/MSA:X/S:X/AU:X/R:X/V:X/RE:X/U:X",
            "cvss_data": {
                "cvss2": {},
                "cvss3": {},
                "cvss4": {
                    "security-advisories@github.com": [
                        {
                            "attackComplexity": "LOW",
                            "attackRequirements": "NONE",
                            "attackVector": "NETWORK",
                            "baseScore": 10,
                            "exploitMaturity": "NOT_DEFINED",
                            "privilegesRequired": "NONE",
                            "subsequent_system_availability": "HIGH",
                            "subsequent_system_confidentiality": "HIGH",
                            "subsequent_system_integrity": "HIGH",
                            "type": "Secondary",
                            "userInteraction": "NONE",
                            "vectorString": "CVSS:4.0/AV:N/AC:L/AT:N/PR:N/UI:N/VC:H/VI:H/VA:H/SC:H/SI:H/SA:H/E:X/CR:X/IR:X/AR:X/MAV:X/MAC:X/MAT:X/MPR:X/MUI:X/MVC:X/MVI:X/MVA:X/MSC:X/MSI:X/MSA:X/S:X/AU:X/R:X/V:X/RE:X/U:X",
                            "vulnerable_system_availability": "HIGH",
                            "vulnerable_system_confidentiality": "HIGH",
                            "vulnerable_system_integrity": "HIGH",
                        }
                    ]
                },
            },
            "cwe": ["CWE-284", "CWE-89"],
            "epss": "0.00043",
            "epssMetric": {
                "lastModified": parse_datetime("2025-02-25T09:09:05"),
                "percentile": "0.11716",
            },
            "exploitability4": {
                "attackcomplexity": "LOW",
                "attackrequirements": "NONE",
                "attackvector": "NETWORK",
                "exploitmaturity": "NOT_DEFINED",
                "privilegesrequired": "NONE",
                "userinteraction": "NONE",
            },
            "id": "CVE-2025-26606",
            "impact": {},
            "impact4": {
                "subsequent_system_availability": "HIGH",
                "subsequent_system_confidentiality": "HIGH",
                "subsequent_system_integrity": "HIGH",
                "vulnerable_system_availability": "HIGH",
                "vulnerable_system_confidentiality": "HIGH",
                "vulnerable_system_integrity": "HIGH",
            },
            "lastModified": parse_datetime("2025-02-18T21:15:28.583000"),
            "modified": parse_datetime("2025-02-18T21:15:28.583000"),
            "published": parse_datetime("2025-02-18T21:15:28.583000"),
            "references": [
                "https://github.com/LabRedesCefetRJ/WeGIA/security/advisories/GHSA-rxjr-cw9q-cwwg"
            ],
            "status": "Received",
            "summary": "WeGIA is an open source Web Manager for Institutions with a focus on Portuguese language users. A SQL Injection vulnerability was discovered in the WeGIA application, informacao_adicional.php endpoint. This vulnerability could allow an attacker to execute arbitrary SQL queries, allowing unauthorized access to sensitive information. This issue has been addressed in version 3.2.13 and all users are advised to upgrade. There are no known workarounds for this vulnerability.",
            "vulnerable_configuration_cpe_2_2": [],
        },
    ],
    "cpe": [
        {
            "title": "Wordpress Dean Logan Wp-People Plugin 1.6.1",
            "cpeName": "cpe:2.3:a:wordpress:dean_logan_wp-people_plugin:1.6.1:*:*:*:*:*:*:*",
            "vendor": "wordpress",
            "product": "dean_logan_wp-people_plugin",
            "id": "8d9041e6a59af093b211f8447540596feccc1dc8",
        },
        {
            "title": "Wordpress Page Flip Image Gallery Plugin 0.1.3",
            "cpeName": "cpe:2.3:a:wordpress:page_flip_image_gallery_plugin:0.1.3:*:*:*:*:*:*:*",
            "vendor": "wordpress",
            "product": "page_flip_image_gallery_plugin",
            "id": "725efec7e0f927cf691e2dbbbd305bab4b187031",
        },
        {
            "title": "Wordpress Wordpress 2.0.6",
            "cpeName": "cpe:2.3:a:wordpress:wordpress:2.0.6:*:*:*:*:*:*:*",
            "vendor": "wordpress",
            "product": "wordpress",
            "id": "61795296ab416170d85b347f2423878091bb0447",
        },
        {
            "title": "Wordpress Wordpress 3.9.9",
            "cpeName": "cpe:2.3:a:wordpress:wordpress:3.9.9:*:*:*:*:*:*:*",
            "vendor": "wordpress",
            "product": "wordpress",
            "id": "6a77c773807325a0fa1ac1a52419f7ddc517db72",
        },
        {
            "title": "Wordpress Wordspew 3.3",
            "cpeName": "cpe:2.3:a:wordpress:wordspew:3.3:*:*:*:*:*:*:*",
            "vendor": "wordpress",
            "product": "wordspew",
            "id": "090fadcd41d66eee335fae5fbd0177b4000b7e27",
        },
    ],
}


database = conf.getMongoConnection()

for collection in data:
    database[collection].insert_many(data[collection])
